==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/sl.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Visoko kontrastna tema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, povečajo pa se možnosti hitre uporabe.",
    "Dark theme (beta)" : "Temna tema (preizkusno)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temna tema zmanjša splošno svetlost vmesnika. Tema je še v razvoju, zato je priporočljivo poslati tudi poročila o napakah, ki jih opazite.",
    "Dyslexia font" : "Pisava za posameznike z disleksijo",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Pisava OpenDyslexic je brezplačna pisava, zasnovana in oblikovana po priporočilih za posameznike z disleksijo. Zmanjša nekatere splošne težave pri branju.",
    "Accessibility" : "Dostopnost",
    "Accessibility options for nextcloud" : "Možnosti dostopnosti za okolje Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Omogoča več možnosti dostopnosti za lažje delo v okolju Nextcloud.",
    "Web Content Accessibility Guidelines" : "Priporočila dostopnosti za spletno vsebino",
    "our issue tracker" : "sledilnik napak",
    "our design team" : "oblikovalska skupina",
    "Enable" : "Omogoči"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/sl.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Visoko kontrastna tema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, povečajo pa se možnosti hitre uporabe.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temna tema zmanjša splošno svetlost vmesnika. Tema je še v razvoju, zato je priporočljivo poslati tudi poročila o napakah, ki jih opazite.",
    "Dyslexia font" : "Pisava za posameznike z disleksijo",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Pisava OpenDyslexic je brezplačna pisava, zasnovana in oblikovana po priporočilih za posameznike z disleksijo. Zmanjša nekatere splošne težave pri branju.",
    "Accessibility" : "Dostopnost",
    "Accessibility options for nextcloud" : "Možnosti dostopnosti za okolje Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Omogoča več možnosti dostopnosti za lažje delo v okolju Nextcloud.",
    "Web Content Accessibility Guidelines" : "Priporočila dostopnosti za spletno vsebino",
    "our issue tracker" : "sledilnik napak",
    "our design team" : "oblikovalska skupina",
    "Enable" : "Omogoči",
    "Dark theme (beta)" : "Temna tema (preizkusno)"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
